#!/bin/sh
# Licensed Materials - Property of IBM
#
# (C) Copyright IBM Corp. 2011, 2013 All Rights Reserved
#
# US Government Users Restricted Rights - Use, duplicate or
# disclosure restricted by GSA ADP Schedule Contract with
# IBM Corp.

CURPATH=$(dirname $0)

. $CURPATH/initSC.sh

LOGFILE=$DIRHOME/log/SCSave.log

#It's for Defect 190012, specifying a new backup directory.
#And the parameter preprocess script is moved into the code StoreageControlExt.java.
TARGET_DIR=$1
BACKUP_DIR=$2

#Set paths.
BACKUPFILE=/tmp/sc_migrate_options.backup
RESTOREFILE=/tmp/sc_migrate_options.restore
export BACKUP_DIR

#Copy files from the Director file structure into our target directory.
function CopySCFiles
{
    if [ ! -d $TARGET_DIR ] ; then
       mkdir $TARGET_DIR
    fi

    if [  -f $DIRHOME/lwi/conf/overrides/etpc.javaopt ] ; then
       cp -f $DIRHOME/lwi/conf/overrides/etpc.javaopt $TARGET_DIR
    fi
    if [ -f $DIRHOME/proddata/advmgr/sc_advmgr.properties ] ; then
       cp -f $DIRHOME/proddata/advmgr/sc_advmgr.properties $TARGET_DIR
    fi
}

#Run SCMigrateDB.java with the specified parameters.
"$JAVAPATH/java" -DBACKUPDIR=$BACKUP_DIR -DBACKUPFILE=$BACKUPFILE -DRESTOREFILE=$RESTOREFILE -cp $CLASSPATH SCMigrateDB $DIRHOME $TPCHOME $*

if [ $? != 0 ] ; then
  displayMessage "MIGRATION_FAILED" >> $LOGFILE
  # Remove the backup and restore files if they exist
  rm -f $BACKUPFILE $RESTOREFILE >> $LOGFILE 2>&1
  exit -5
fi

#If the backup file exists, then run the SCMigDBSupport.sh
if [ -f $BACKUPFILE ] ; then
  $DIRHOME/StorageControl/bin/SCMigDBSupport.sh $BACKUPFILE $DIRHOME
  if [ $? != 0 ] ; then
     displayMessage "MIGRATION_BACKUP_FAILED" >> $LOGFILE
     # Remove the backup and restore files if they exist
     rm -f $BACKUPFILE $RESTOREFILE >> $LOGFILE 2>&1
     exit -8
  fi
  CopySCFiles
else
  displayMessage "MIGRATION_BACKUP_NOT_FOUND" >> $LOGFILE
  # Remove the backup and restore files if they exist
  rm -f $BACKUPFILE $RESTOREFILE >> $LOGFILE 2>&1
  exit -6
fi

if [ $? -eq 0 ] ; then
   displayMessage "SCSAVE_SUCCESS" >> $LOGFILE
   # Remove the backup and restore files if they exist
   rm -f $BACKUPFILE $RESTOREFILE >> $LOGFILE 2>&1
else
   displayMessage "SCSAVE_FAILED" >> $LOGFILE
   # Remove the backup and restore files if they exist
   rm -f $BACKUPFILE $RESTOREFILE >> $LOGFILE 2>&1
fi
